@@ -10,11 +10,22 @@
 # least once, maybe twice (if it needs the base-version ABI information
 # and hasn't cached it).
 
+# The build settings can be influenced via environment variables:
+#   * QT_VERSION    set to nothing (uses default), 5 or 6
+
+case "$QT_VERSION" in
+	5) extra_cmake_args="-DWITH_QT6=OFF" ;;
+	6) extra_cmake_args="-DWITH_QT6=ON" ;;
+	"") extra_cmake_args="" ;;
+	*) echo "Invalid QT_VERSION environment '${QT_VERSION}'" ; exit 1 ; ;;
+esac
+
 # The base version can be a tag or git-hash; it will be checked-out
 # in a worktree.
 #
-# Note that the hash here corresponds to v3.3.0 .
-BASE_VERSION=1d8a1972422d83c36f2b934c2629ae1f564c0428
+# Note that the hash here corresponds to v3.3.3 . That was a release
+# with hidden visibility enabled and a first step towards more-stable ABI.
+BASE_VERSION=8741c7ec1a94ee5f27e98ef3663d1a8f4738d2c2
 
 ### Build a tree and cache the ABI info into ci/
 #
@@ -27,9 +38,11 @@ do_build() {
 	rm -rf $BUILD_DIR
 	rm -f $BUILD_DIR.log
 
-	cmake -S $SOURCE_DIR -B $BUILD_DIR -DCMAKE_BUILD_TYPE=Debug -DCMAKE_CXX_FLAGS="-Og -g -gdwarf" -DCMAKE_C_FLAGS="-Og -g -gdwarf"  > /dev/null 2>&1
+	echo "# Running CMake for $LABEL"
+	cmake -S $SOURCE_DIR -B $BUILD_DIR -DCMAKE_BUILD_TYPE=Debug -DCMAKE_CXX_FLAGS="-Og -g -gdwarf" -DCMAKE_C_FLAGS="-Og -g -gdwarf" $extra_cmake_args > /dev/null 2>&1
 	test -f $BUILD_DIR/Makefile || { echo "! failed to CMake $LABEL" ; exit 1 ; }
 
+	echo "# Running make for $LABEL"
 	# Two targets make knows about at top-level
 	if make -C $BUILD_DIR -j12 calamares calamaresui > $BUILD_DIR.log 2>&1
 	then
@@ -40,6 +53,7 @@ do_build() {
 			cp $lib ci/`basename $lib`.$LABEL
 		done
 		rm -rf $BUILD_DIR $BUILD_DIR.log
+		echo "# .. build successful for $LABEL"
 	else
 		echo "! failed to build $LABEL"
 		exit 1
