@@ -55,7 +55,7 @@ done
 # .tx/config file to locate files, and overwrites them in the
 # filesystem with new (merged) translations.
 export QT_SELECT=5
-tx pull --force --source --all
+transifex-client pull --force --all || exit 1
 
 
 ### CLEANUP TRANSLATIONS
@@ -69,9 +69,6 @@ drop_language() {
 	mv calamares.desktop.new calamares.desktop
 }
 
-drop_language es_ES
-drop_language pl_PL
-
 # Also fix the .desktop file, which has some fields removed by Transifex.
 #
 { cat calamares.desktop.in ; grep "\\[[a-zA-Z_@]*]=" calamares.desktop ; } > calamares.desktop.new
@@ -108,6 +105,21 @@ awk '
 		skip=0; print $0;
 	}}' < calamares.desktop > calamares.desktop.new
 mv calamares.desktop.new calamares.desktop
+# Now group translated key-names (Name, Icon, Description, ..) by sorted
+# language key rather than random-ish language-key order (which shuffles
+# entries around).
+#
+# First, the non-translated lines
+grep -v '\[.*\]=' calamares.desktop  > calamares.desktop.new
+# The translated lines:
+# - replace (the first) [] by | so we have a consistent field separator
+# - sort based on field 2, then 1 (language code, then reversed key-name)
+# - replace the first | by [, the first (remaining) | by ]
+# Effectively this puts the fields in this order: Name, Icon, Generic Name,
+# Comment -- within each language key. This keeps churn down since the
+# language codes and key-names are constant.
+grep '\[.*\]=' calamares.desktop | sed -e 's/\[/|/' -e 's/\]/|/' | sort -t '|' -k 2,2 -k 1,1r | sed -e 's/|/\[/' | sed -e 's/|/\]/' >> calamares.desktop.new
+mv calamares.desktop.new calamares.desktop
 git add --verbose calamares.desktop
 git commit "$AUTHOR" --message="i18n: [desktop] $BOILERPLATE" | true
 
@@ -116,6 +128,19 @@ git commit "$AUTHOR" --message="i18n: [desktop] $BOILERPLATE" | true
 # PO-Created line). This applies only to modules which use po-files.
 git diff --numstat src/modules | awk '($1==1 && $2==1){print $3}' | xargs git checkout --
 
+# sed either wants -i'' (GNU sed) or -i '' (BSD sed) to
+# replace in a file, with no backup extension. Define
+# a `reinplace` command to deal with the difference.
+if test FreeBSD = `uname` ; then
+	reinplace() { 
+		sed -i '' "$@"
+	}
+else
+	reinplace() { 
+		sed -i'' "$@"
+	}
+fi
+
 # Go through the Python modules; those with a lang/ subdir have their
 # own complete gettext-based setup.
 for MODULE_DIR in $(find src/modules -maxdepth 1 -mindepth 1 -type d) ; do
@@ -125,7 +150,7 @@ for MODULE_DIR in $(find src/modules -maxdepth 1 -mindepth 1 -type d) ; do
 		if [ -d ${MODULE_DIR}/lang ]; then
 			# Convert PO files to MO files
 			for POFILE in $(find ${MODULE_DIR} -name "*.po") ; do
-				sed -i'' '/^"Content-Type/s/CHARSET/UTF-8/' $POFILE
+				reinplace '/^"Content-Type/s/CHARSET/UTF-8/' $POFILE
 				# msgfmt -o ${POFILE%.po}.mo $POFILE
 			done
 			git add --verbose ${MODULE_DIR}/lang/*
@@ -135,7 +160,7 @@ for MODULE_DIR in $(find src/modules -maxdepth 1 -mindepth 1 -type d) ; do
 done
 
 for POFILE in $(find lang -name "python.po") ; do
-	sed -i'' '/^"Content-Type/s/CHARSET/UTF-8/' $POFILE
+	reinplace '/^"Content-Type/s/CHARSET/UTF-8/' $POFILE
 	# msgfmt -o ${POFILE%.po}.mo $POFILE
 done
 git add --verbose lang/python*
