@@ -26,9 +26,6 @@ public:
 protected:
     QSize sizeHint( const QStyleOptionViewItem& option, const QModelIndex& index ) const override;
     void paint( QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index ) const override;
-
-private:
-    void paintViewStep( QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index ) const;
 };
 
 #endif  // PROGRESSTREEDELEGATE_H
