@@ -32,6 +32,7 @@ private Q_SLOTS:
     void testGSLoadSave();
     void testGSLoadSave2();
     void testGSLoadSaveYAMLStringList();
+    void testGSNestedLookup();
 
     void testInstanceKey();
     void testInstanceDescription();
@@ -126,17 +127,14 @@ TestLibCalamares::testGSLoadSave2()
 {
     Logger::setupLogLevel( Logger::LOGDEBUG );
 
-    const QString filename( "../src/libcalamares/testdata/yaml-list.conf" );
-    if ( !QFile::exists( filename ) )
-    {
-        return;
-    }
+    const QString filename( BUILD_AS_TEST "/testdata/yaml-list.conf" );
+    QVERIFY2( QFile::exists( filename ), qPrintable( filename ) );
 
     Calamares::GlobalStorage gs1;
     const QString key( "dwarfs" );
 
     QVERIFY( gs1.loadYaml( filename ) );
-    QCOMPARE( gs1.count(), 3 );  // From examining the file
+    QCOMPARE( gs1.count(), 4 );  // From examining the file
     QVERIFY( gs1.contains( key ) );
     cDebug() << Calamares::typeOf( gs1.value( key ) ) << gs1.value( key );
     QCOMPARE( Calamares::typeOf( gs1.value( key ) ), Calamares::ListVariantType );
@@ -177,6 +175,38 @@ TestLibCalamares::testGSLoadSaveYAMLStringList()
     QCOMPARE( gs2.value( "dwarfs" ).toString(), QStringLiteral( "<QStringList>" ) );  // .. they're gone
 }
 
+void
+TestLibCalamares::testGSNestedLookup()
+{
+    Logger::setupLogLevel( Logger::LOGDEBUG );
+
+    const QString filename( BUILD_AS_TEST "/testdata/yaml-list.conf" );
+    QVERIFY2( QFile::exists( filename ), qPrintable( filename ) );
+
+    Calamares::GlobalStorage gs2;
+    QVERIFY( gs2.loadYaml( filename ) );
+
+    bool ok = false;
+    const auto v0 = Calamares::lookup( &gs2, "horse.colors.neck", ok );
+    QVERIFY( ok );
+    QVERIFY( v0.canConvert< QString >() );
+    QCOMPARE( v0.toString(), QStringLiteral( "roan" ) );
+    const auto v1 = Calamares::lookup( &gs2, "horse.colors.nose", ok );
+    QVERIFY( !ok );
+    QVERIFY( !v1.isValid() );
+    const auto v2 = Calamares::lookup( &gs2, "cow.colors.nose", ok );
+    QVERIFY( !ok );
+    QVERIFY( !v2.isValid() );
+    const auto v3 = Calamares::lookup( &gs2, "dwarfs", ok );
+    QVERIFY( ok );
+    QVERIFY( v3.canConvert< QVariantList >() );  // because it's a list-valued thing
+    const auto v4 = Calamares::lookup( &gs2, "dwarfs.sleepy", ok );
+    QVERIFY( !ok );  // Sleepy is a value in the list of dwarfs, not a key
+    const auto v5 = Calamares::lookup( &gs2, "derp", ok );
+    QVERIFY( ok );
+    QCOMPARE( v5.toInt(), 17 );
+}
+
 void
 TestLibCalamares::testInstanceKey()
 {
