@@ -8,13 +8,14 @@
 
 #include "AutoMount.h"
 
+#include "compat/Variant.h"
 #include "utils/Logger.h"
 
 #include <QtDBus>
 
 #include <optional>
 
-namespace CalamaresUtils
+namespace Calamares
 {
 namespace Partition
 {
@@ -29,20 +30,25 @@ struct AutoMountInfo
  *
  * KDE Solid automount management.
  *
- * Solid can be influenced through DBus calls to kded5. The following code
- * handles Solid: if Solid exists (e.g. we're in a KDE Plasma desktop)
+ * Solid can be influenced through DBus calls to kded (both kded5 and kded6). The
+ * following code handles Solid: if Solid exists (e.g. we're in a KDE Plasma desktop)
  * then try to turn off automount that way.
  */
 
-/** @brief Boilerplate for a call to kded5
+/** @brief Boilerplate for a call to kded
  *
  * Returns a method-call message, ready for arguments and call().
  */
 static inline QDBusMessage
 kdedCall( const QString& method )
 {
+#if QT_VERSION < QT_VERSION_CHECK( 6, 0, 0 )
     return QDBusMessage::createMethodCall(
         QStringLiteral( "org.kde.kded5" ), QStringLiteral( "/kded" ), QStringLiteral( "org.kde.kded5" ), method );
+#else
+    return QDBusMessage::createMethodCall(
+        QStringLiteral( "org.kde.kded6" ), QStringLiteral( "/kded" ), QStringLiteral( "org.kde.kded6" ), method );
+#endif
 }
 
 /** @brief Log a response from call()
@@ -114,7 +120,7 @@ querySolidAutoMount( QDBusConnection& dbus, AutoMountInfo& info )
         if ( arg.length() == 1 )
         {
             auto v = arg.at( 0 );
-            if ( v.isValid() && v.type() == QVariant::Bool )
+            if ( v.isValid() && Calamares::typeOf( v ) == Calamares::BoolVariantType )
             {
                 result = v.toBool();
             }
@@ -167,4 +173,4 @@ automountRestore( const std::shared_ptr< AutoMountInfo >& info )
 }
 
 }  // namespace Partition
-}  // namespace CalamaresUtils
+}  // namespace Calamares
