@@ -12,13 +12,14 @@
 #include "Mount.h"
 
 #include "partition/Sync.h"
-#include "utils/CalamaresUtilsSystem.h"
 #include "utils/Logger.h"
+#include "utils/String.h"
+#include "utils/System.h"
 
 #include <QDir>
 #include <QTemporaryDir>
 
-namespace CalamaresUtils
+namespace Calamares
 {
 namespace Partition
 {
@@ -37,7 +38,7 @@ mount( const QString& devicePath, const QString& mountPoint, const QString& file
             cWarning() << "Can't mount on an empty mountpoint.";
         }
 
-        return static_cast< int >( ProcessResult::Code::NoWorkingDirectory );
+        return static_cast< int >( Calamares::ProcessResult::Code::NoWorkingDirectory );
     }
 
     QDir mountPointDir( mountPoint );
@@ -47,7 +48,7 @@ mount( const QString& devicePath, const QString& mountPoint, const QString& file
         if ( !ok )
         {
             cWarning() << "Could not create mountpoint" << mountPoint;
-            return static_cast< int >( ProcessResult::Code::NoWorkingDirectory );
+            return static_cast< int >( Calamares::ProcessResult::Code::NoWorkingDirectory );
         }
     }
 
@@ -70,7 +71,7 @@ mount( const QString& devicePath, const QString& mountPoint, const QString& file
     }
     args << devicePath << mountPoint;
 
-    auto r = CalamaresUtils::System::runCommand( args, std::chrono::seconds( 10 ) );
+    auto r = Calamares::System::runCommand( args, std::chrono::seconds( 10 ) );
     sync();
     return r.getExitCode();
 }
@@ -78,8 +79,7 @@ mount( const QString& devicePath, const QString& mountPoint, const QString& file
 int
 unmount( const QString& path, const QStringList& options )
 {
-    auto r
-        = CalamaresUtils::System::runCommand( QStringList { "umount" } << options << path, std::chrono::seconds( 10 ) );
+    auto r = Calamares::System::runCommand( QStringList { "umount" } << options << path, std::chrono::seconds( 10 ) );
     sync();
     return r.getExitCode();
 }
@@ -90,9 +90,8 @@ struct TemporaryMount::Private
     QTemporaryDir m_mountDir;
 };
 
-
 TemporaryMount::TemporaryMount( const QString& devicePath, const QString& filesystemName, const QString& options )
-    : m_d( new Private )
+    : m_d( std::make_unique< Private >() )
 {
     m_d->m_devicePath = devicePath;
     m_d->m_mountDir.setAutoRemove( false );
@@ -100,8 +99,7 @@ TemporaryMount::TemporaryMount( const QString& devicePath, const QString& filesy
     if ( r )
     {
         cWarning() << "Mount of" << devicePath << "on" << m_d->m_mountDir.path() << "failed, code" << r;
-        delete m_d;
-        m_d = nullptr;
+        m_d.reset();
     }
 }
 
@@ -115,8 +113,6 @@ TemporaryMount::~TemporaryMount()
             cWarning() << "UnMount of temporary" << m_d->m_devicePath << "on" << m_d->m_mountDir.path()
                        << "failed, code" << r;
         }
-        delete m_d;
-        m_d = nullptr;
     }
 }
 
@@ -126,5 +122,38 @@ TemporaryMount::path() const
     return m_d ? m_d->m_mountDir.path() : QString();
 }
 
+QList< MtabInfo >
+MtabInfo::fromMtabFilteredByPrefix( const QString& mountPrefix, const QString& mtabPath )
+{
+    QFile f( mtabPath.isEmpty() ? "/etc/mtab" : mtabPath );
+    if ( !f.open( QIODevice::ReadOnly | QIODevice::Text ) )
+    {
+        return {};
+    }
+
+    QList< MtabInfo > l;
+    // After opening, atEnd() is already true (!?) so try reading at least once
+    do
+    {
+        QString line = f.readLine();
+        if ( line.isEmpty() || line.startsWith( '#' ) )
+        {
+            continue;
+        }
+
+        QStringList parts = line.split( ' ', SplitSkipEmptyParts );
+        if ( parts.length() >= 3 && !parts[ 0 ].startsWith( '#' ) )
+        {
+            // Lines have format: <device> <mountpoint> <fstype> <options>..., so check
+            // the mountpoint field. Everything starts with an empty string.
+            if ( parts[ 1 ].startsWith( mountPrefix ) )
+            {
+                l.append( { parts[ 0 ], parts[ 1 ] } );
+            }
+        }
+    } while ( !f.atEnd() );
+    return l;
+}
+
 }  // namespace Partition
-}  // namespace CalamaresUtils
+}  // namespace Calamares
