@@ -189,8 +189,9 @@ Calamares::Utils::Runner::run()
                                        ? ( static_cast< int >( std::chrono::milliseconds( m_timeout ).count() ) )
                                        : -1 ) )
     {
-        cWarning() << "Process" << m_command.first() << "timed out after" << m_timeout.count() << "ms. Output so far:\n"
-                   << Logger::NoQuote << process.readAllStandardOutput();
+        cWarning() << "Process" << m_command.first() << "timed out after" << m_timeout.count() << "ms."
+                   << Logger::NoQuote << "Output so far:\n"
+                   << process.readAllStandardOutput();
         return ProcessResult::Code::TimedOut;
     }
 
@@ -216,7 +217,7 @@ Calamares::Utils::Runner::run()
 
     if ( process.exitStatus() == QProcess::CrashExit )
     {
-        cWarning() << "Process" << m_command.first() << "crashed. Output so far:\n" << Logger::NoQuote << output;
+        cWarning() << "Process" << m_command.first() << "crashed." << Logger::NoQuote << "Output so far:\n" << output;
         return ProcessResult::Code::Crashed;
     }
 
@@ -226,7 +227,7 @@ Calamares::Utils::Runner::run()
     {
         if ( showDebug && !output.isEmpty() )
         {
-            cDebug() << Logger::SubEntry << "Finished. Exit code:" << r << "output:\n" << Logger::NoQuote << output;
+            cDebug() << Logger::SubEntry << "Finished. Exit code:" << r << Logger::NoQuote << "output:\n" << output;
         }
     }
     else  // if ( r != 0 )
@@ -234,8 +235,8 @@ Calamares::Utils::Runner::run()
         if ( !output.isEmpty() )
         {
             cDebug() << Logger::SubEntry << "Target cmd:" << Logger::RedactedCommand( m_command ) << "Exit code:" << r
-                     << "output:\n"
-                     << Logger::NoQuote << output;
+                     << Logger::NoQuote << "output:\n"
+                     << output;
         }
         else
         {
