@@ -50,6 +50,12 @@ class UIDLLEXPORT ViewManager : public QAbstractListModel
     ///@brief Sides on which the ViewManager has side-panels
     Q_PROPERTY( Qt::Orientations panelSides READ panelSides WRITE setPanelSides MEMBER m_panelSides )
 
+    // Global properties, where ViewManager proxies to Settings
+    Q_PROPERTY( bool isDebugMode READ isDebugMode CONSTANT FINAL )
+    Q_PROPERTY( bool isChrootMode READ isChrootMode CONSTANT FINAL )
+    Q_PROPERTY( bool isSetupMode READ isSetupMode CONSTANT FINAL )
+    Q_PROPERTY( QString logFilePath READ logFilePath CONSTANT FINAL )
+
 public:
     /**
      * @brief instance access to the ViewManager singleton.
@@ -95,14 +101,21 @@ public:
      */
     int currentStepIndex() const;
 
+    enum class Confirmation
+    {
+        Continue,  // User rejects cancel / close question
+        CancelInstallation,  // User accepts cancel / close question
+        EndOfInstallation,  // There was no question because the installation was already done
+    };
+
     /**
      * @brief Called when "Cancel" is clicked; asks for confirmation.
      * Other means of closing Calamares also call this method, e.g. alt-F4.
      * At the end of installation, no confirmation is asked.
      *
-     * @return @c true if the user confirms closing the window.
+     * @return a Confirmation value, @c Unasked if the installation is complete
      */
-    bool confirmCancelInstallation();
+    Confirmation confirmCancelInstallation();
 
     Qt::Orientations panelSides() const { return m_panelSides; }
     void setPanelSides( Qt::Orientations panelSides ) { m_panelSides = panelSides; }
@@ -197,6 +210,15 @@ public Q_SLOTS:
     /// @brief Connected to ViewStep::nextStatusChanged for all steps
     void updateNextStatus( bool enabled );
 
+    /// @brief Proxy to Settings::debugMode() default @c false
+    bool isDebugMode() const;
+    /// @brief Proxy to Settings::doChroot() default @c true
+    bool isChrootMode() const;
+    /// @brief Proxy to Settings::isSetupMode() default @c false
+    bool isSetupMode() const;
+    /// @brief Proxy to Logger::logFile(), default empty
+    QString logFilePath() const;
+
 signals:
     void currentStepChanged();
     void ensureSize( QSize size ) const;  // See ViewStep::ensureSize()
