@@ -34,7 +34,6 @@ ModuleManager::instance()
     return s_instance;
 }
 
-
 ModuleManager::ModuleManager( const QStringList& paths, QObject* parent )
     : QObject( parent )
     , m_paths( paths )
@@ -44,7 +43,6 @@ ModuleManager::ModuleManager( const QStringList& paths, QObject* parent )
     s_instance = this;
 }
 
-
 ModuleManager::~ModuleManager()
 {
     // The map is populated with Module::fromDescriptor(), which allocates on the heap.
@@ -54,7 +52,6 @@ ModuleManager::~ModuleManager()
     }
 }
 
-
 void
 ModuleManager::init()
 {
@@ -98,7 +95,7 @@ ModuleManager::doInit()
                     }
 
                     bool ok = false;
-                    QVariantMap moduleDescriptorMap = CalamaresUtils::loadYaml( descriptorFileInfo, &ok );
+                    QVariantMap moduleDescriptorMap = Calamares::YAML::load( descriptorFileInfo, &ok );
                     QString moduleName = ok ? moduleDescriptorMap.value( "name" ).toString() : QString();
 
                     if ( ok && !moduleName.isEmpty() && ( moduleName == currentDir.dirName() )
@@ -136,14 +133,12 @@ ModuleManager::doInit()
     QTimer::singleShot( 10, this, &ModuleManager::initDone );
 }
 
-
 QList< ModuleSystem::InstanceKey >
 ModuleManager::loadedInstanceKeys()
 {
     return m_loadedModulesByInstanceKey.keys();
 }
 
-
 Calamares::ModuleSystem::Descriptor
 ModuleManager::moduleDescriptor( const QString& name )
 {
@@ -156,7 +151,6 @@ ModuleManager::moduleInstance( const ModuleSystem::InstanceKey& instanceKey )
     return m_loadedModulesByInstanceKey.value( instanceKey );
 }
 
-
 /** @brief Returns the config file name for the given @p instanceKey
  *
  * Custom instances have custom config files, non-custom ones
@@ -185,7 +179,6 @@ getConfigFileName( const Settings::InstanceDescriptionList& descriptorList,
         }
     }
 
-
     // This should already have been checked and failed the module already
     return QString();
 }
@@ -214,7 +207,7 @@ ModuleManager::loadModules()
                 continue;
             }
 
-            ModuleSystem::Descriptor descriptor
+            const ModuleSystem::Descriptor descriptor
                 = m_availableDescriptorsByModuleName.value( instanceKey.module(), ModuleSystem::Descriptor() );
             if ( !descriptor.isValid() )
             {
@@ -349,7 +342,18 @@ ModuleManager::checkRequirements()
     connect( rq,
              &RequirementsChecker::done,
              this,
-             [ = ]() { this->requirementsComplete( m_requirementsModel->satisfiedMandatory() ); } );
+             [ = ]()
+             {
+                 if ( m_requirementsModel->satisfiedMandatory() )
+                 {
+                     /* we're done */ this->requirementsComplete( true );
+                 }
+                 else
+                 {
+                     this->requirementsComplete( false );
+                     QTimer::singleShot( std::chrono::seconds( 5 ), this, &ModuleManager::checkRequirements );
+                 }
+             } );
 
     QTimer::singleShot( 0, rq, &RequirementsChecker::run );
 }
@@ -416,11 +420,13 @@ ModuleManager::checkModuleDependencies( const Module& m )
     {
         bool requirementFound = false;
         for ( const Module* v : m_loadedModulesByInstanceKey )
+        {
             if ( required == v->name() )
             {
                 requirementFound = true;
                 break;
             }
+        }
         if ( !requirementFound )
         {
             cError() << "Module" << m.name() << "requires" << required << "before it in sequence.";
