@@ -12,7 +12,7 @@
 #include <QPixmap>
 
 #include "DllMacro.h"
-#include "utils/CalamaresUtilsGui.h"
+#include "utils/Gui.h"
 
 class UIDLLEXPORT ImageRegistry
 {
@@ -21,13 +21,12 @@ public:
 
     explicit ImageRegistry();
 
-    QIcon icon( const QString& image, CalamaresUtils::ImageMode mode = CalamaresUtils::Original );
-    QPixmap
-    pixmap( const QString& image, const QSize& size, CalamaresUtils::ImageMode mode = CalamaresUtils::Original );
+    QIcon icon( const QString& image, Calamares::ImageMode mode = Calamares::Original );
+    QPixmap pixmap( const QString& image, const QSize& size, Calamares::ImageMode mode = Calamares::Original );
 
 private:
     qint64 cacheKey( const QSize& size );
-    void putInCache( const QString& image, const QSize& size, CalamaresUtils::ImageMode mode, const QPixmap& pixmap );
+    void putInCache( const QString& image, const QSize& size, Calamares::ImageMode mode, const QPixmap& pixmap );
 };
 
 #endif  // IMAGE_REGISTRY_H
