@@ -26,7 +26,7 @@
 
 static QDir s_qmlModulesDir( QString( CMAKE_INSTALL_FULL_DATADIR ) + "/qml" );
 
-namespace CalamaresUtils
+namespace Calamares
 {
 QDir
 qmlModulesDir()
@@ -46,9 +46,9 @@ qmlDirCandidates( bool assumeBuilddir )
     static const char QML[] = "qml";
 
     QStringList qmlDirs;
-    if ( CalamaresUtils::isAppDataDirOverridden() )
+    if ( Calamares::isAppDataDirOverridden() )
     {
-        qmlDirs << CalamaresUtils::appDataDir().absoluteFilePath( QML );
+        qmlDirs << Calamares::appDataDir().absoluteFilePath( QML );
     }
     else
     {
@@ -56,12 +56,14 @@ qmlDirCandidates( bool assumeBuilddir )
         {
             qmlDirs << QDir::current().absoluteFilePath( "src/qml" );  // In build-dir
         }
-        if ( CalamaresUtils::haveExtraDirs() )
-            for ( auto s : CalamaresUtils::extraDataDirs() )
+        if ( Calamares::haveExtraDirs() )
+        {
+            for ( auto s : Calamares::extraDataDirs() )
             {
                 qmlDirs << ( s + QML );
             }
-        qmlDirs << CalamaresUtils::appDataDir().absoluteFilePath( QML );
+        }
+        qmlDirs << Calamares::appDataDir().absoluteFilePath( QML );
     }
 
     return qmlDirs;
@@ -79,14 +81,14 @@ initQmlModulesDir()
         if ( dir.exists() && dir.isReadable() )
         {
             cDebug() << "Using Calamares QML directory" << dir.absolutePath();
-            CalamaresUtils::setQmlModulesDir( dir );
+            Calamares::setQmlModulesDir( dir );
             return true;
         }
     }
 
     cError() << "Cowardly refusing to continue startup without a QML directory."
              << Logger::DebugList( qmlDirCandidatesByPriority );
-    if ( CalamaresUtils::isAppDataDirOverridden() )
+    if ( Calamares::isAppDataDirOverridden() )
     {
         cError() << "FATAL: explicitly configured application data directory is missing qml/";
     }
@@ -135,14 +137,14 @@ addExpansions( QmlSearch method, QStringList& candidates, const QStringList& nam
         std::transform( names.constBegin(),
                         names.constEnd(),
                         std::back_inserter( candidates ),
-                        [&]( const QString& s ) { return s.isEmpty() ? QString() : bPath.arg( brandDir, s ); } );
+                        [ & ]( const QString& s ) { return s.isEmpty() ? QString() : bPath.arg( brandDir, s ); } );
     }
     if ( ( method == QmlSearch::Both ) || ( method == QmlSearch::QrcOnly ) )
     {
         std::transform( names.constBegin(),
                         names.constEnd(),
                         std::back_inserter( candidates ),
-                        [&]( const QString& s ) { return s.isEmpty() ? QString() : qrPath.arg( s ); } );
+                        [ & ]( const QString& s ) { return s.isEmpty() ? QString() : qrPath.arg( s ); } );
     }
 }
 
@@ -222,23 +224,31 @@ registerQmlModels()
         // Because branding and viewmanager have a parent (CalamaresApplication
         // and CalamaresWindow), they will not be deleted by QmlEngine.
         //   https://doc.qt.io/qt-5/qtqml-cppintegration-data.html#data-ownership
-        qmlRegisterSingletonType< Calamares::Branding >(
-            "io.calamares.ui", 1, 0, "Branding", []( QQmlEngine*, QJSEngine* ) -> QObject* {
-                return Calamares::Branding::instance();
-            } );
-        qmlRegisterSingletonType< Calamares::ViewManager >(
-            "io.calamares.ui", 1, 0, "ViewManager", []( QQmlEngine*, QJSEngine* ) -> QObject* {
-                return Calamares::ViewManager::instance();
-            } );
+        qmlRegisterSingletonType< Calamares::Branding >( "io.calamares.ui",
+                                                         1,
+                                                         0,
+                                                         "Branding",
+                                                         []( QQmlEngine*, QJSEngine* ) -> QObject*
+                                                         { return Calamares::Branding::instance(); } );
+        qmlRegisterSingletonType< Calamares::ViewManager >( "io.calamares.ui",
+                                                            1,
+                                                            0,
+                                                            "ViewManager",
+                                                            []( QQmlEngine*, QJSEngine* ) -> QObject*
+                                                            { return Calamares::ViewManager::instance(); } );
         qmlRegisterSingletonType< Calamares::GlobalStorage >(
-            "io.calamares.core", 1, 0, "Global", []( QQmlEngine*, QJSEngine* ) -> QObject* {
-                return Calamares::JobQueue::instance()->globalStorage();
-            } );
-        qmlRegisterSingletonType< CalamaresUtils::Network::Manager >(
-            "io.calamares.core", 1, 0, "Network", []( QQmlEngine*, QJSEngine* ) -> QObject* {
-                return &CalamaresUtils::Network::Manager::instance();
-            } );
+            "io.calamares.core",
+            1,
+            0,
+            "Global",
+            []( QQmlEngine*, QJSEngine* ) -> QObject* { return Calamares::JobQueue::instance()->globalStorage(); } );
+        qmlRegisterSingletonType< Calamares::Network::Manager >( "io.calamares.core",
+                                                                 1,
+                                                                 0,
+                                                                 "Network",
+                                                                 []( QQmlEngine*, QJSEngine* ) -> QObject*
+                                                                 { return new Calamares::Network::Manager; } );
     }
 }
 
-}  // namespace CalamaresUtils
+}  // namespace Calamares
