@@ -24,7 +24,9 @@ void
 FixedAspectRatioLabel::setPixmap( const QPixmap& pixmap )
 {
     m_pixmap = pixmap;
-    QLabel::setPixmap( pixmap.scaled( contentsRect().size(), Qt::KeepAspectRatio, Qt::SmoothTransformation ) );
+    m_pixmap.setDevicePixelRatio( devicePixelRatio() );
+    QLabel::setPixmap( m_pixmap.scaled(
+        contentsRect().size() * m_pixmap.devicePixelRatio(), Qt::KeepAspectRatio, Qt::SmoothTransformation ) );
 }
 
 
@@ -32,5 +34,6 @@ void
 FixedAspectRatioLabel::resizeEvent( QResizeEvent* event )
 {
     Q_UNUSED( event )
-    QLabel::setPixmap( m_pixmap.scaled( contentsRect().size(), Qt::KeepAspectRatio, Qt::SmoothTransformation ) );
+    QLabel::setPixmap( m_pixmap.scaled(
+        contentsRect().size() * m_pixmap.devicePixelRatio(), Qt::KeepAspectRatio, Qt::SmoothTransformation ) );
 }
