@@ -9,7 +9,7 @@
 
 #include "PrettyRadioButton.h"
 
-#include "utils/CalamaresUtilsGui.h"
+#include "utils/Gui.h"
 #include "widgets/ClickableLabel.h"
 
 #include <QButtonGroup>
@@ -20,6 +20,8 @@
 
 namespace Calamares
 {
+namespace Widgets
+{
 
 PrettyRadioButton::PrettyRadioButton( QWidget* parent )
     : QWidget( parent )
@@ -124,5 +126,5 @@ PrettyRadioButton::toggleOptions( bool toggle )
         m_optionsLayout->parentWidget()->setVisible( toggle );
     }
 }
-
+}  // namespace Widgets
 }  // namespace Calamares
