@@ -9,8 +9,8 @@
 
 #include "InitramfsJob.h"
 
-#include "utils/CalamaresUtilsSystem.h"
 #include "utils/Logger.h"
+#include "utils/System.h"
 #include "utils/UMask.h"
 #include "utils/Variant.h"
 
@@ -21,18 +21,16 @@ InitramfsJob::InitramfsJob( QObject* parent )
 
 InitramfsJob::~InitramfsJob() {}
 
-
 QString
 InitramfsJob::prettyName() const
 {
-    return tr( "Creating initramfs." );
+    return tr( "Creating initramfs…", "@status" );
 }
 
-
 Calamares::JobResult
 InitramfsJob::exec()
 {
-    CalamaresUtils::UMask m( CalamaresUtils::UMask::Safe );
+    Calamares::UMask m( Calamares::UMask::Safe );
 
     cDebug() << "Updating initramfs with kernel" << m_kernel;
 
@@ -45,7 +43,7 @@ InitramfsJob::exec()
         // First make sure we generate a safe initramfs with suitable permissions.
         static const char confFile[] = "/etc/initramfs-tools/conf.d/calamares-safe-initramfs.conf";
         static const char contents[] = "UMASK=0077\n";
-        if ( CalamaresUtils::System::instance()->createTargetFile( confFile, QByteArray( contents ) ).failed() )
+        if ( Calamares::System::instance()->createTargetFile( confFile, QByteArray( contents ) ).failed() )
         {
             cWarning() << Logger::SubEntry << "Could not configure safe UMASK for initramfs.";
             // But continue anyway.
@@ -53,27 +51,26 @@ InitramfsJob::exec()
     }
 
     // And then do the ACTUAL work.
-    auto r = CalamaresUtils::System::instance()->targetEnvCommand(
+    auto r = Calamares::System::instance()->targetEnvCommand(
         { "update-initramfs", "-k", m_kernel, "-c", "-t" }, QString(), QString() /* no timeout, 0 */ );
     return r.explainProcess( "update-initramfs", std::chrono::seconds( 10 ) /* fake timeout */ );
 }
 
-
 void
 InitramfsJob::setConfigurationMap( const QVariantMap& configurationMap )
 {
-    m_kernel = CalamaresUtils::getString( configurationMap, "kernel" );
+    m_kernel = Calamares::getString( configurationMap, "kernel" );
     if ( m_kernel.isEmpty() )
     {
         m_kernel = QStringLiteral( "all" );
     }
     else if ( m_kernel == "$uname" )
     {
-        auto r = CalamaresUtils::System::runCommand( CalamaresUtils::System::RunLocation::RunInHost,
-                                                     { "/bin/uname", "-r" },
-                                                     QString(),
-                                                     QString(),
-                                                     std::chrono::seconds( 3 ) );
+        auto r = Calamares::System::runCommand( Calamares::System::RunLocation::RunInHost,
+                                                { "/bin/uname", "-r" },
+                                                QString(),
+                                                QString(),
+                                                std::chrono::seconds( 3 ) );
         if ( r.getExitCode() == 0 )
         {
             m_kernel = r.getOutput();
@@ -81,12 +78,13 @@ InitramfsJob::setConfigurationMap( const QVariantMap& configurationMap )
         }
         else
         {
+            m_kernel = QStringLiteral( "all" );
             cWarning() << "*initramfs* could not determine running kernel, using 'all'." << Logger::Continuation
                        << r.getExitCode() << r.getOutput();
         }
     }
 
-    m_unsafe = CalamaresUtils::getBool( configurationMap, "be_unsafe", false );
+    m_unsafe = Calamares::getBool( configurationMap, "be_unsafe", false );
 }
 
 CALAMARES_PLUGIN_FACTORY_DEFINITION( InitramfsJobFactory, registerPlugin< InitramfsJob >(); )
