@@ -83,10 +83,12 @@ public:
 
     const Calamares::Locale::TimeZoneData* currentLocation() const { return m_currentLocation; }
 
-
     /// Special case, set location from starting timezone if not already set
     void setCurrentLocation();
 
+    /// Restores original timezone, if any
+    void cancel();
+
 private:
     Calamares::Locale::TimeZoneData* currentLocation_c() const
     {
@@ -176,6 +178,9 @@ private:
      */
     Calamares::GeoIP::RegionZonePair m_startingTimezone;
 
+    /// @brief The timezone set in the system when Calamares started (not from config)
+    Calamares::GeoIP::RegionZonePair m_originalTimezone;
+
     /** @brief Handler for GeoIP lookup (if configured)
      *
      * The GeoIP lookup needs to be started at some suitable time,
