@@ -130,6 +130,12 @@ LocaleViewStep::onLeave()
     m_config->finalizeGlobalStorage();
 }
 
+void
+LocaleViewStep::onCancel()
+{
+    m_config->cancel();
+}
+
 void
 LocaleViewStep::setConfigurationMap( const QVariantMap& configurationMap )
 {
