@@ -34,8 +34,9 @@ public:
     bool isAtBeginning() const override;
     bool isAtEnd() const override;
 
-    virtual void onActivate() override;
-    virtual void onLeave() override;
+    void onActivate() override;
+    void onLeave() override;
+    void onCancel() override;
 
     Calamares::JobList jobs() const override;
 
