@@ -12,6 +12,8 @@
 
 #include "Workers.h"
 
+#include "MachineIdJob.h"
+
 #include "utils/Entropy.h"
 #include "utils/Logger.h"
 #include "utils/System.h"
@@ -46,9 +48,6 @@ getUrandomPoolSize()
     return ( poolSize >= minimumPoolSize ) ? poolSize : minimumPoolSize;
 }
 
-namespace MachineId
-{
-
 static inline bool
 isAbsolutePath( const QString& fileName )
 {
@@ -61,19 +60,19 @@ copyFile( const QString& rootMountPoint, const QString& fileName )
     if ( !isAbsolutePath( fileName ) )
     {
         return Calamares::JobResult::internalError(
-            QObject::tr( "File not found" ),
-            QObject::tr( "Path <pre>%1</pre> must be an absolute path." ).arg( fileName ),
+            MachineIdJob::tr( "File not found" ),
+            MachineIdJob::tr( "Path <pre>%1</pre> must be an absolute path." ).arg( fileName ),
             0 );
     }
 
     QFile f( fileName );
     if ( !f.exists() )
     {
-        return Calamares::JobResult::error( QObject::tr( "File not found" ), fileName );
+        return Calamares::JobResult::error( MachineIdJob::tr( "File not found" ), fileName );
     }
     if ( !f.copy( rootMountPoint + fileName ) )
     {
-        return Calamares::JobResult::error( QObject::tr( "File not found" ), rootMountPoint + fileName );
+        return Calamares::JobResult::error( MachineIdJob::tr( "File not found" ), rootMountPoint + fileName );
     }
     return Calamares::JobResult::ok();
 }
@@ -90,8 +89,8 @@ createNewEntropy( int poolSize, const QString& rootMountPoint, const QString& fi
     if ( !entropyFile.open( QIODevice::WriteOnly ) )
     {
         return Calamares::JobResult::error(
-            QObject::tr( "File not found" ),
-            QObject::tr( "Could not create new random file <pre>%1</pre>." ).arg( fileName ) );
+            MachineIdJob::tr( "File not found" ),
+            MachineIdJob::tr( "Could not create new random file <pre>%1</pre>." ).arg( fileName ) );
     }
 
     QByteArray data;
@@ -190,5 +189,3 @@ createDBusLink( const QString& rootMountPoint, const QString& fileName, const QS
     Q_UNUSED( rootMountPoint )
     return runCmd( QStringList { QStringLiteral( "ln" ), QStringLiteral( "-sf" ), systemdFileName, fileName }, true );
 }
-
-}  // namespace MachineId
