@@ -16,6 +16,7 @@
 
 #include "GlobalStorage.h"
 #include "JobQueue.h"
+#include "compat/Variant.h"
 #include "network/Manager.h"
 #include "packages/Globals.h"
 #include "utils/Logger.h"
@@ -41,7 +42,6 @@ Config::retranslate()
     emit titleLabelChanged( titleLabel() );
 }
 
-
 QString
 Config::status() const
 {
@@ -63,7 +63,6 @@ Config::status() const
     __builtin_unreachable();
 }
 
-
 void
 Config::setStatus( Status s )
 {
@@ -83,7 +82,6 @@ Config::titleLabel() const
     return m_titleLabel ? m_titleLabel->get() : QString();
 }
 
-
 void
 Config::loadGroupList( const QVariantList& groupData )
 {
@@ -97,7 +95,6 @@ Config::loadGroupList( const QVariantList& groupData )
     {
         setStatus( Status::Ok );
     }
-    emit statusReady();
 }
 
 void
@@ -108,17 +105,17 @@ Config::loadingDone()
         m_queue->deleteLater();
         m_queue = nullptr;
     }
+    emit statusReady();
 }
 
-
 void
 Config::setConfigurationMap( const QVariantMap& configurationMap )
 {
-    setRequired( CalamaresUtils::getBool( configurationMap, "required", false ) );
+    setRequired( Calamares::getBool( configurationMap, "required", false ) );
 
     // Get the translations, if any
     bool bogus = false;
-    auto label = CalamaresUtils::getSubMap( configurationMap, "label", bogus );
+    auto label = Calamares::getSubMap( configurationMap, "label", bogus );
     // Use a different class name for translation lookup because the
     // .. table of strings lives in NetInstallViewStep.cpp and moving them
     // .. around is annoying for translators.
@@ -126,35 +123,33 @@ Config::setConfigurationMap( const QVariantMap& configurationMap )
 
     if ( label.contains( "sidebar" ) )
     {
-        m_sidebarLabel = new CalamaresUtils::Locale::TranslatedString( label, "sidebar", className );
+        m_sidebarLabel = new Calamares::Locale::TranslatedString( label, "sidebar", className );
     }
     if ( label.contains( "title" ) )
     {
-        m_titleLabel = new CalamaresUtils::Locale::TranslatedString( label, "title", className );
+        m_titleLabel = new Calamares::Locale::TranslatedString( label, "title", className );
     }
 
     // Lastly, load the groups data
     const QString key = QStringLiteral( "groupsUrl" );
     const auto& groupsUrlVariant = configurationMap.value( key );
-    if ( groupsUrlVariant.type() == QVariant::String )
+    m_queue = new LoaderQueue( this );
+    if ( Calamares::typeOf( groupsUrlVariant ) == Calamares::StringVariantType )
     {
-        m_queue = new LoaderQueue( this );
         m_queue->append( SourceItem::makeSourceItem( groupsUrlVariant.toString(), configurationMap ) );
     }
-    else if ( groupsUrlVariant.type() == QVariant::List )
+    else if ( Calamares::typeOf( groupsUrlVariant ) == Calamares::ListVariantType )
     {
-        m_queue = new LoaderQueue( this );
         for ( const auto& s : groupsUrlVariant.toStringList() )
         {
             m_queue->append( SourceItem::makeSourceItem( s, configurationMap ) );
         }
     }
-    if ( m_queue && m_queue->count() > 0 )
-    {
-        cDebug() << "Loading netinstall from" << m_queue->count() << "alternate sources.";
-        connect( m_queue, &LoaderQueue::done, this, &Config::loadingDone );
-        m_queue->load();
-    }
+
+    setStatus( required() ? Status::FailedNoData : Status::Ok );
+    cDebug() << "Loading netinstall from" << m_queue->count() << "alternate sources.";
+    connect( m_queue, &LoaderQueue::done, this, &Config::loadingDone );
+    m_queue->load();
 }
 
 void
@@ -179,6 +174,6 @@ Config::finalizeGlobalStorage( const Calamares::ModuleSystem::InstanceKey& key )
         }
     }
 
-    CalamaresUtils::Packages::setGSPackageAdditions(
+    Calamares::Packages::setGSPackageAdditions(
         Calamares::JobQueue::instance()->globalStorage(), key, installPackages, tryInstallPackages );
 }
