@@ -1,4 +1,3 @@
-
 /* === This file is part of Calamares - <https://calamares.io> ===
  *
  *   SPDX-FileCopyrightText: 2017 Kyle Robbertze <kyle@aims.ac.za>
@@ -21,7 +20,7 @@
 namespace YAML
 {
 class Node;
-}
+}  // namespace YAML
 
 class PackageModel : public QAbstractItemModel
 {
