@@ -14,15 +14,14 @@
 #include "ItemAppData.h"
 #endif
 
-#ifdef HAVE_APPSTREAM
+#ifdef HAVE_APPSTREAM_VERSION
 #include "ItemAppStream.h"
-#include <AppStreamQt/pool.h>
 #include <memory>
 #endif
 
-
 #include "GlobalStorage.h"
 #include "JobQueue.h"
+#include "compat/Variant.h"
 #include "packages/Globals.h"
 #include "utils/Logger.h"
 #include "utils/Variant.h"
@@ -113,9 +112,9 @@ Config::introductionPackage() const
             = QT_TR_NOOP( "Please pick a product from the list. The selected product will be installed." );
         defaultIntroduction = new PackageItem( QString(), name, description );
         defaultIntroduction->screenshot = QPixmap( QStringLiteral( ":/images/no-selection.png" ) );
-        defaultIntroduction->name = CalamaresUtils::Locale::TranslatedString( name, metaObject()->className() );
+        defaultIntroduction->name = Calamares::Locale::TranslatedString( name, metaObject()->className() );
         defaultIntroduction->description
-            = CalamaresUtils::Locale::TranslatedString( description, metaObject()->className() );
+            = Calamares::Locale::TranslatedString( description, metaObject()->className() );
     }
     return *defaultIntroduction;
 }
@@ -143,7 +142,7 @@ Config::updateGlobalStorage( const QStringList& selected ) const
     {
         QStringList packageNames = m_model->getInstallPackagesForNames( selected );
         cDebug() << m_defaultId << "packages to install" << packageNames;
-        CalamaresUtils::Packages::setGSPackageAdditions(
+        Calamares::Packages::setGSPackageAdditions(
             Calamares::JobQueue::instance()->globalStorage(), m_defaultId, packageNames );
     }
     else if ( m_method == PackageChooserMethod::NetAdd )
@@ -175,7 +174,7 @@ Config::updateGlobalStorage( const QStringList& selected ) const
         if ( gs->contains( "netinstallSelect" ) )
         {
             auto selectedOrig = gs->value( "netinstallSelect" );
-            if ( selectedOrig.canConvert( QVariant::StringList ) )
+            if ( selectedOrig.canConvert< QStringList >() )
             {
                 newSelected += selectedOrig.toStringList();
             }
@@ -222,7 +221,6 @@ Config::updateGlobalStorage() const
     }
 }
 
-
 void
 Config::setPackageChoice( const QString& packageChoice )
 {
@@ -258,7 +256,7 @@ fillModel( PackageListModel* model, const QVariantList& items )
         return;
     }
 
-#ifdef HAVE_APPSTREAM
+#ifdef HAVE_APPSTREAM_VERSION
     std::unique_ptr< AppStream::Pool > pool;
     bool poolOk = false;
 #endif
@@ -285,7 +283,7 @@ fillModel( PackageListModel* model, const QVariantList& items )
         }
         else if ( item_map.contains( "appstream" ) )
         {
-#ifdef HAVE_APPSTREAM
+#ifdef HAVE_APPSTREAM_VERSION
             if ( !pool )
             {
                 pool = std::make_unique< AppStream::Pool >();
@@ -311,9 +309,9 @@ fillModel( PackageListModel* model, const QVariantList& items )
 void
 Config::setConfigurationMap( const QVariantMap& configurationMap )
 {
-    m_mode = packageChooserModeNames().find( CalamaresUtils::getString( configurationMap, "mode" ),
+    m_mode = packageChooserModeNames().find( Calamares::getString( configurationMap, "mode" ),
                                              PackageChooserMode::Required );
-    m_method = PackageChooserMethodNames().find( CalamaresUtils::getString( configurationMap, "method" ),
+    m_method = PackageChooserMethodNames().find( Calamares::getString( configurationMap, "method" ),
                                                  PackageChooserMethod::Legacy );
 
     if ( m_method == PackageChooserMethod::Legacy )
@@ -325,7 +323,7 @@ Config::setConfigurationMap( const QVariantMap& configurationMap )
     {
         fillModel( m_model, configurationMap.value( "items" ).toList() );
 
-        QString default_item_id = CalamaresUtils::getString( configurationMap, "default" );
+        QString default_item_id = Calamares::getString( configurationMap, "default" );
         if ( !default_item_id.isEmpty() )
         {
             for ( int item_n = 0; item_n < m_model->packageCount(); ++item_n )
@@ -343,7 +341,7 @@ Config::setConfigurationMap( const QVariantMap& configurationMap )
     }
     else
     {
-        setPackageChoice( CalamaresUtils::getString( configurationMap, "packageChoice" ) );
+        setPackageChoice( Calamares::getString( configurationMap, "packageChoice" ) );
         if ( m_method != PackageChooserMethod::Legacy )
         {
             cWarning() << "Single-selection QML module must use 'Legacy' method.";
@@ -351,12 +349,12 @@ Config::setConfigurationMap( const QVariantMap& configurationMap )
     }
 
     bool labels_ok = false;
-    auto labels = CalamaresUtils::getSubMap( configurationMap, "labels", labels_ok );
+    auto labels = Calamares::getSubMap( configurationMap, "labels", labels_ok );
     if ( labels_ok )
     {
         if ( labels.contains( "step" ) )
         {
-            m_stepName = new CalamaresUtils::Locale::TranslatedString( labels, "step" );
+            m_stepName = new Calamares::Locale::TranslatedString( labels, "step" );
         }
     }
 }
