@@ -112,7 +112,7 @@ PackageListModel::addPackage( PackageItem&& p )
 QStringList
 PackageListModel::getInstallPackagesForName( const QString& id ) const
 {
-    for ( const auto& p : qAsConst( m_packages ) )
+    for ( const auto& p : std::as_const( m_packages ) )
     {
         if ( p.id == id )
         {
@@ -126,7 +126,7 @@ QStringList
 PackageListModel::getInstallPackagesForNames( const QStringList& ids ) const
 {
     QStringList l;
-    for ( const auto& p : qAsConst( m_packages ) )
+    for ( const auto& p : std::as_const( m_packages ) )
     {
         if ( ids.contains( p.id ) )
         {
