@@ -25,7 +25,9 @@
 #include <kpmcore/fs/luks.h>
 #include <kpmcore/util/externalcommand.h>
 
-using CalamaresUtils::Partition::PartitionIterator;
+#include <qregularexpression.h>
+
+using Calamares::Partition::PartitionIterator;
 
 namespace KPMHelpers
 {
@@ -82,6 +84,7 @@ createNewEncryptedPartition( PartitionNode* parent,
                              const QString& fsLabel,
                              qint64 firstSector,
                              qint64 lastSector,
+                             Config::LuksGeneration luksFsType,
                              const QString& passphrase,
                              PartitionTable::Flags flags )
 {
@@ -91,8 +94,10 @@ createNewEncryptedPartition( PartitionNode* parent,
         newRoles |= PartitionRole::Luks;
     }
 
+    FileSystem::Type luksType = luksGenerationToFSName( luksFsType );
+
     FS::luks* fs = dynamic_cast< FS::luks* >(
-        FileSystemFactory::create( FileSystem::Luks, firstSector, lastSector, device.logicalSize() ) );
+        FileSystemFactory::create( luksType, firstSector, lastSector, device.logicalSize() ) );
     if ( !fs )
     {
         cError() << "cannot create LUKS filesystem. Giving up.";
@@ -133,45 +138,6 @@ clonePartition( Device* device, Partition* partition )
                           partition->activeFlags() );
 }
 
-#ifndef WITH_KPMCORE4API
-// This function was added in KPMCore 4, implementation copied from src/fs/luks.cpp
-/*
-    SPDX-FileCopyrightText: 2010 Volker Lanz <vl@fidra.de>
-    SPDX-FileCopyrightText: 2012-2019 Andrius Štikonas <andrius@stikonas.eu>
-    SPDX-FileCopyrightText: 2015-2016 Teo Mrnjavac <teo@kde.org>
-    SPDX-FileCopyrightText: 2016 Chantara Tith <tith.chantara@gmail.com>
-    SPDX-FileCopyrightText: 2017 Christian Morlok <christianmorlok@gmail.com>
-    SPDX-FileCopyrightText: 2018 Caio Jordão Carvalho <caiojcarvalho@gmail.com>
-    SPDX-FileCopyrightText: 2020 Arnaud Ferraris <arnaud.ferraris@collabora.com>
-    SPDX-FileCopyrightText: 2020 Gaël PORTAY <gael.portay@collabora.com>
-
-    SPDX-License-Identifier: GPL-3.0-or-later
-*/
-static bool
-testPassphrase( FS::luks* fs, const QString& deviceNode, const QString& passphrase )
-{
-    ExternalCommand cmd( QStringLiteral( "cryptsetup" ),
-                         { QStringLiteral( "open" ),
-                           QStringLiteral( "--tries" ),
-                           QStringLiteral( "1" ),
-                           QStringLiteral( "--test-passphrase" ),
-                           deviceNode } );
-    if ( cmd.write( passphrase.toLocal8Bit() + '\n' ) && cmd.start( -1 ) && cmd.exitCode() == 0 )
-    {
-        return true;
-    }
-
-    return false;
-}
-#else
-static bool
-testPassphrase( FS::luks* fs, const QString& deviceNode, const QString& passphrase )
-{
-    return fs->testPassphrase( deviceNode, passphrase );
-}
-#endif
-
-// Adapted from src/fs/luks.cpp cryptOpen which always opens a dialog to ask for a passphrase
 SavePassphraseValue
 savePassphrase( Partition* partition, const QString& passphrase )
 {
@@ -181,59 +147,176 @@ savePassphrase( Partition* partition, const QString& passphrase )
         return SavePassphraseValue::EmptyPassphrase;
     }
 
-    if ( partition->fileSystem().type() != FileSystem::Luks )
+    FS::luks* luksFs = dynamic_cast< FS::luks* >( &partition->fileSystem() );
+    if ( luksFs == nullptr )
     {
+        // No luks device
         return SavePassphraseValue::NotLuksPartition;
     }
 
-    FS::luks* luksFs = dynamic_cast< FS::luks* >( &partition->fileSystem() );
-    const QString deviceNode = partition->partitionPath();
-
     // Test the given passphrase
-    if ( !testPassphrase( luksFs, deviceNode, passphrase ) )
+    if ( !luksFs->testPassphrase( partition->partitionPath(), passphrase ) )
+    {
+        // Save the existing passphrase
+        luksFs->setPassphrase( passphrase );
+    }
+    else
     {
         return SavePassphraseValue::IncorrectPassphrase;
     }
+    return SavePassphraseValue::NoError;
+}
+
+// Adapted from src/fs/luks.cpp cryptOpen which always opens a dialog to ask for a passphrase
+QString
+cryptOpen( Partition* partition )
+{
+    FS::luks* luksFs = dynamic_cast< FS::luks* >( &partition->fileSystem() );
+    if ( luksFs == nullptr )
+    {
+        // No luks device
+        return QString();
+    }
 
     if ( luksFs->isCryptOpen() )
     {
         if ( !luksFs->mapperName().isEmpty() )
         {
-            return SavePassphraseValue::NoError;
+            // Already decrypted
+            return luksFs->mapperName();
         }
         else
         {
-            cDebug() << Logger::SubEntry << "No mapper node found";
+            cDebug() << Logger::SubEntry << "No mapper node found - reset cryptOpen";
             luksFs->setCryptOpen( false );
         }
     }
 
+    if ( luksFs->passphrase().isEmpty() )
+    {
+        // No passphrase for decryption
+        return QString();
+    }
+
+    // Decrypt the partition
+    const QString deviceNode = partition->partitionPath();
     ExternalCommand openCmd( QStringLiteral( "cryptsetup" ),
                              { QStringLiteral( "open" ), deviceNode, luksFs->suggestedMapperName( deviceNode ) } );
-    if ( !( openCmd.write( passphrase.toLocal8Bit() + '\n' ) && openCmd.start( -1 ) && openCmd.exitCode() == 0 ) )
+    if ( ( openCmd.write( luksFs->passphrase().toLocal8Bit() + '\n' ) && openCmd.start( -1 )
+           && openCmd.exitCode() == 0 ) )
     {
-        cWarning() << Logger::SubEntry << openCmd.exitCode() << ": cryptsetup command failed";
-        return SavePassphraseValue::CryptsetupError;
+        luksFs->scan( deviceNode );
+        if ( luksFs->mapperName().isEmpty() )
+        {
+            return QString();
+        }
+        luksFs->loadInnerFileSystem( luksFs->mapperName() );
+        luksFs->setCryptOpen( luksFs->innerFS() != nullptr );
+        if ( !luksFs->isCryptOpen() )
+        {
+            return QString();
+        }
+        return luksFs->mapperName();
+    }
+    return QString();
+}
+
+void
+cryptClose( Partition* partition )
+{
+    FS::luks* luksFs = dynamic_cast< FS::luks* >( &partition->fileSystem() );
+    if ( luksFs == nullptr )
+    {
+        // No luks device
+        return;
     }
 
-    // Save the existing passphrase
-    luksFs->setPassphrase( passphrase );
-    luksFs->scan( deviceNode );
     if ( luksFs->mapperName().isEmpty() )
     {
-        return SavePassphraseValue::NoMapperNode;
+        // Not opened
+        return;
     }
 
-    luksFs->loadInnerFileSystem( luksFs->mapperName() );
-    luksFs->setCryptOpen( luksFs->innerFS() != nullptr );
-    if ( !luksFs->isCryptOpen() )
-    {
-        return SavePassphraseValue::DeviceNotDecrypted;
-    }
-
-    return SavePassphraseValue::NoError;
+    // Close the partition
+    luksFs->cryptClose( partition->partitionPath() );
 }
 
+bool
+cryptLabel( Partition* partition, const QString& label )
+{
+    int version = cryptVersion( partition );
+    if ( version == 0 || label.isEmpty() )
+    {
+        return false;
+    }
+
+    if ( version == 1 )
+    {
+        QString mappedDevice = cryptOpen( partition );
+        if ( !mappedDevice.isEmpty() )
+        {
+            // Label mapped device
+            ExternalCommand openCmd( QStringLiteral( "e2label" ), { mappedDevice, label } );
+            openCmd.start( -1 );
+            cryptClose( partition );
+            return true;
+        }
+    }
+    else
+    {
+        ExternalCommand openCmd(
+            QStringLiteral( "cryptsetup" ),
+            { QStringLiteral( "config" ), partition->partitionPath(), QStringLiteral( "--label" ), label } );
+        if ( openCmd.start( -1 ) && openCmd.exitCode() == 0 )
+        {
+            return true;
+        }
+    }
+    return false;
+}
+
+int
+cryptVersion( Partition* partition )
+{
+    if ( partition->fileSystem().type() != FileSystem::Luks )
+    {
+        return 0;
+    }
+
+    // Get luks version from header information
+    int luksVersion = 1;
+    ExternalCommand openCmd( QStringLiteral( "cryptsetup" ),
+                             { QStringLiteral( "luksDump" ), partition->partitionPath() } );
+    if ( openCmd.start( -1 ) && openCmd.exitCode() == 0 )
+    {
+        QRegularExpression re( QStringLiteral( R"(version:\s+(\d))" ), QRegularExpression::CaseInsensitiveOption );
+        QRegularExpressionMatch rem = re.match( openCmd.output() );
+        if ( rem.hasMatch() )
+        {
+            luksVersion = rem.captured( 1 ).toInt();
+        }
+    }
+    return luksVersion;
+}
+
+FileSystem::Type
+luksGenerationToFSName( Config::LuksGeneration luksGeneration )
+{
+    // Convert luksGenerationChoice from partition.conf into its
+    // corresponding file system type from KPMCore.
+    switch ( luksGeneration )
+    {
+    case Config::LuksGeneration::Luks2:
+        return FileSystem::Type::Luks2;
+    case Config::LuksGeneration::Luks1:
+        return FileSystem::Type::Luks;
+    default:
+        cWarning() << "luksGeneration not supported, defaulting to \"luks\"";
+        return FileSystem::Type::Luks;
+    }
+}
+
+
 Calamares::JobResult
 execute( Operation& operation, const QString& failureMessage )
 {
@@ -247,7 +330,7 @@ execute( Operation& operation, const QString& failureMessage )
 
     // Remove the === lines from the report by trimming them to empty
     QStringList l = report.toText().split( '\n' );
-    std::for_each( l.begin(), l.end(), []( QString& s ) { CalamaresUtils::removeLeading( s, '=' ); } );
+    std::for_each( l.begin(), l.end(), []( QString& s ) { Calamares::String::removeLeading( s, '=' ); } );
 
     return Calamares::JobResult::error( failureMessage, l.join( '\n' ) );
 }
