@@ -19,7 +19,7 @@
 #include <QDialog>
 #include <QScopedPointer>
 
-
+class PartitionCoreModule;
 class Device;
 class Partition;
 class PartitionNode;
@@ -39,7 +39,8 @@ private:
      *
      * This does all the shared UI setup.
      */
-    CreatePartitionDialog( Device* device,
+    CreatePartitionDialog( PartitionCoreModule* core,
+                           Device* device,
                            PartitionNode* parentPartition,
                            const QStringList& usedMountPoints,
                            QWidget* parentWidget );
@@ -59,7 +60,8 @@ public:
      * Creating from free space makes a wholly new partition with
      * no flags set at all.
      */
-    CreatePartitionDialog( Device* device,
+    CreatePartitionDialog( PartitionCoreModule* core,
+                           Device* device,
                            const FreeSpace& freeSpacePartition,
                            const QStringList& usedMountPoints,
                            QWidget* parentWidget = nullptr );
@@ -68,7 +70,8 @@ public:
      * A partition previously newly created (e.g. via this dialog
      * and the constructor above) can be re-edited.
      */
-    CreatePartitionDialog( Device* device,
+    CreatePartitionDialog( PartitionCoreModule* core,
+                           Device* device,
                            const FreshPartition& existingNewPartition,
                            const QStringList& usedMountPoints,
                            QWidget* parentWidget = nullptr );
@@ -84,6 +87,7 @@ private Q_SLOTS:
 
 private:
     QScopedPointer< Ui_CreatePartitionDialog > m_ui;
+    PartitionCoreModule* m_core;
     PartitionSizeController* m_partitionSizeController;
     Device* m_device;
     PartitionNode* m_parent;
