@@ -32,7 +32,13 @@ class EditExistingPartitionDialog : public QDialog
 {
     Q_OBJECT
 public:
-    EditExistingPartitionDialog( Device* device,
+    struct FreeSpace
+    {
+        Partition* p;
+    };
+
+    EditExistingPartitionDialog( PartitionCoreModule* core,
+                                 Device* device,
                                  Partition* partition,
                                  const QStringList& usedMountPoints,
                                  QWidget* parentWidget = nullptr );
@@ -45,6 +51,7 @@ private slots:
 
 private:
     QScopedPointer< Ui_EditExistingPartitionDialog > m_ui;
+    PartitionCoreModule* m_core;
     Device* m_device;
     Partition* m_partition;
     PartitionSizeController* m_partitionSizeController;
@@ -53,6 +60,7 @@ private:
     PartitionTable::Flags newFlags() const;
     void replacePartResizerWidget();
     void updateMountPointPicker();
+    void toggleEncryptWidget();
 };
 
 #endif /* EDITEXISTINGPARTITIONDIALOG_H */
