@@ -13,6 +13,8 @@
 #ifndef ENCRYPTWIDGET_H
 #define ENCRYPTWIDGET_H
 
+#include "compat/CheckBox.h"
+
 #include <QWidget>
 
 #include <kpmcore/fs/filesystem.h>
@@ -36,7 +38,7 @@ public:
 
     explicit EncryptWidget( QWidget* parent = nullptr );
 
-    void setEncryptionCheckbox( bool preCheckEncrypt = false);
+    void setEncryptionCheckbox( bool preCheckEncrypt = false );
     void reset( bool checkVisible = true );
 
     bool isEncryptionCheckboxChecked();
@@ -59,7 +61,7 @@ signals:
 private:
     void updateState( const bool notify = true );
     void onPassphraseEdited();
-    void onCheckBoxStateChanged( int checked );
+    void onCheckBoxStateChanged( Calamares::checkBoxStateType checked );
 
     Ui::EncryptWidget* m_ui;
     Encryption m_state;
