@@ -14,7 +14,7 @@
 #include "core/PartitionModel.h"
 #include "core/SizeUtils.h"
 
-#include "utils/CalamaresUtilsGui.h"
+#include "utils/Gui.h"
 #include "utils/Logger.h"
 #include "utils/Units.h"
 
@@ -26,23 +26,21 @@
 #include <QMouseEvent>
 #include <QPainter>
 
-using namespace CalamaresUtils::Units;
+using namespace Calamares::Units;
 
 static const int LAYOUT_MARGIN = 4;
-static const int LABEL_PARTITION_SQUARE_MARGIN = qMax( QFontMetrics( CalamaresUtils::defaultFont() ).ascent() - 2, 18 );
+static const int LABEL_PARTITION_SQUARE_MARGIN = qMax( Calamares::defaultFontHeight() - 2, 18 );
 static const int LABELS_MARGIN = LABEL_PARTITION_SQUARE_MARGIN;
 static const int CORNER_RADIUS = 2;
 
-
 static QStringList
 buildUnknownDisklabelTexts( Device* dev )
 {
-    QStringList texts = { QObject::tr( "Unpartitioned space or unknown partition table" ),
+    QStringList texts = { QObject::tr( "Unpartitioned space or unknown partition table", "@info" ),
                           formatByteSize( dev->totalLogical() * dev->logicalSize() ) };
     return texts;
 }
 
-
 PartitionLabelsView::PartitionLabelsView( QWidget* parent )
     : QAbstractItemView( parent )
     , m_canBeSelected( []( const QModelIndex& ) { return true; } )
@@ -56,17 +54,14 @@ PartitionLabelsView::PartitionLabelsView( QWidget* parent )
     setMouseTracking( true );
 }
 
-
 PartitionLabelsView::~PartitionLabelsView() {}
 
-
 QSize
 PartitionLabelsView::minimumSizeHint() const
 {
     return sizeHint();
 }
 
-
 QSize
 PartitionLabelsView::sizeHint() const
 {
@@ -78,7 +73,6 @@ PartitionLabelsView::sizeHint() const
     return QSize();
 }
 
-
 void
 PartitionLabelsView::paintEvent( QPaintEvent* event )
 {
@@ -93,14 +87,12 @@ PartitionLabelsView::paintEvent( QPaintEvent* event )
     drawLabels( &painter, lRect, QModelIndex() );
 }
 
-
 QRect
 PartitionLabelsView::labelsRect() const
 {
     return rect().adjusted( 0, LAYOUT_MARGIN, 0, 0 );
 }
 
-
 static void
 drawPartitionSquare( QPainter* painter, const QRect& rect, const QBrush& brush )
 {
@@ -112,7 +104,6 @@ drawPartitionSquare( QPainter* painter, const QRect& rect, const QBrush& brush )
     painter->translate( -.5, -.5 );
 }
 
-
 static void
 drawSelectionSquare( QPainter* painter, const QRect& rect, const QBrush& brush )
 {
@@ -128,7 +119,6 @@ drawSelectionSquare( QPainter* painter, const QRect& rect, const QBrush& brush )
     painter->restore();
 }
 
-
 QModelIndexList
 PartitionLabelsView::getIndexesToDraw( const QModelIndex& parent ) const
 {
@@ -167,7 +157,6 @@ PartitionLabelsView::getIndexesToDraw( const QModelIndex& parent ) const
     return list;
 }
 
-
 QStringList
 PartitionLabelsView::buildTexts( const QModelIndex& index ) const
 {
@@ -190,28 +179,28 @@ PartitionLabelsView::buildTexts( const QModelIndex& index ) const
             }
             else if ( mountPoint == "/home" )
             {
-                firstLine = tr( "Home" );
+                firstLine = tr( "Home", "@label" );
             }
             else if ( mountPoint == "/boot" )
             {
-                firstLine = tr( "Boot" );
+                firstLine = tr( "Boot", "@label" );
             }
             else if ( mountPoint.contains( "/efi" )
                       && index.data( PartitionModel::FileSystemTypeRole ).toInt() == FileSystem::Fat32 )
             {
-                firstLine = tr( "EFI system" );
+                firstLine = tr( "EFI system", "@label" );
             }
             else if ( index.data( PartitionModel::FileSystemTypeRole ).toInt() == FileSystem::LinuxSwap )
             {
-                firstLine = tr( "Swap" );
+                firstLine = tr( "Swap", "@label" );
             }
             else if ( !mountPoint.isEmpty() )
             {
-                firstLine = tr( "New partition for %1" ).arg( mountPoint );
+                firstLine = tr( "New partition for %1", "@label" ).arg( mountPoint );
             }
             else
             {
-                firstLine = tr( "New partition" );
+                firstLine = tr( "New partition", "@label" );
             }
         }
     }
@@ -234,15 +223,16 @@ PartitionLabelsView::buildTexts( const QModelIndex& index ) const
         secondLine = index.sibling( index.row(), PartitionModel::SizeColumn ).data().toString();
     }
     else
+    {
         //: size[number]  filesystem[name]
         secondLine = tr( "%1  %2" )
                          .arg( index.sibling( index.row(), PartitionModel::SizeColumn ).data().toString() )
                          .arg( index.sibling( index.row(), PartitionModel::FileSystemColumn ).data().toString() );
+    }
 
     return { firstLine, secondLine };
 }
 
-
 void
 PartitionLabelsView::drawLabels( QPainter* painter, const QRect& rect, const QModelIndex& parent )
 {
@@ -304,7 +294,6 @@ PartitionLabelsView::drawLabels( QPainter* painter, const QRect& rect, const QMo
     }
 }
 
-
 QSize
 PartitionLabelsView::sizeForAllLabels( int maxLineWidth ) const
 {
@@ -348,7 +337,6 @@ PartitionLabelsView::sizeForAllLabels( int maxLineWidth ) const
     return QSize( maxLineWidth, totalHeight );
 }
 
-
 QSize
 PartitionLabelsView::sizeForLabel( const QStringList& text ) const
 {
@@ -365,7 +353,6 @@ PartitionLabelsView::sizeForLabel( const QStringList& text ) const
     return QSize( width, vertOffset );
 }
 
-
 void
 PartitionLabelsView::drawLabel( QPainter* painter,
                                 const QStringList& text,
@@ -398,7 +385,6 @@ PartitionLabelsView::drawLabel( QPainter* painter,
     painter->setPen( Qt::black );
 }
 
-
 QModelIndex
 PartitionLabelsView::indexAt( const QPoint& point ) const
 {
@@ -437,7 +423,6 @@ PartitionLabelsView::indexAt( const QPoint& point ) const
     return QModelIndex();
 }
 
-
 QRect
 PartitionLabelsView::visualRect( const QModelIndex& idx ) const
 {
@@ -475,7 +460,6 @@ PartitionLabelsView::visualRect( const QModelIndex& idx ) const
     return QRect();
 }
 
-
 QRegion
 PartitionLabelsView::visualRegionForSelection( const QItemSelection& selection ) const
 {
@@ -484,21 +468,18 @@ PartitionLabelsView::visualRegionForSelection( const QItemSelection& selection )
     return QRegion();
 }
 
-
 int
 PartitionLabelsView::horizontalOffset() const
 {
     return 0;
 }
 
-
 int
 PartitionLabelsView::verticalOffset() const
 {
     return 0;
 }
 
-
 void
 PartitionLabelsView::scrollTo( const QModelIndex& index, ScrollHint hint )
 {
@@ -506,7 +487,6 @@ PartitionLabelsView::scrollTo( const QModelIndex& index, ScrollHint hint )
     Q_UNUSED( hint )
 }
 
-
 void
 PartitionLabelsView::setCustomNewRootLabel( const QString& text )
 {
@@ -514,7 +494,6 @@ PartitionLabelsView::setCustomNewRootLabel( const QString& text )
     viewport()->repaint();
 }
 
-
 void
 PartitionLabelsView::setSelectionModel( QItemSelectionModel* selectionModel )
 {
@@ -522,21 +501,18 @@ PartitionLabelsView::setSelectionModel( QItemSelectionModel* selectionModel )
     connect( selectionModel, &QItemSelectionModel::selectionChanged, this, [ = ] { viewport()->repaint(); } );
 }
 
-
 void
 PartitionLabelsView::setSelectionFilter( SelectionFilter canBeSelected )
 {
     m_canBeSelected = canBeSelected;
 }
 
-
 void
 PartitionLabelsView::setExtendedPartitionHidden( bool hidden )
 {
     m_extendedPartitionHidden = hidden;
 }
 
-
 QModelIndex
 PartitionLabelsView::moveCursor( CursorAction cursorAction, Qt::KeyboardModifiers modifiers )
 {
@@ -546,7 +522,6 @@ PartitionLabelsView::moveCursor( CursorAction cursorAction, Qt::KeyboardModifier
     return QModelIndex();
 }
 
-
 bool
 PartitionLabelsView::isIndexHidden( const QModelIndex& index ) const
 {
@@ -555,7 +530,6 @@ PartitionLabelsView::isIndexHidden( const QModelIndex& index ) const
     return false;
 }
 
-
 void
 PartitionLabelsView::setSelection( const QRect& rect, QItemSelectionModel::SelectionFlags flags )
 {
@@ -566,7 +540,6 @@ PartitionLabelsView::setSelection( const QRect& rect, QItemSelectionModel::Selec
     }
 }
 
-
 void
 PartitionLabelsView::mouseMoveEvent( QMouseEvent* event )
 {
@@ -597,7 +570,6 @@ PartitionLabelsView::mouseMoveEvent( QMouseEvent* event )
     }
 }
 
-
 void
 PartitionLabelsView::leaveEvent( QEvent* event )
 {
@@ -611,7 +583,6 @@ PartitionLabelsView::leaveEvent( QEvent* event )
     }
 }
 
-
 void
 PartitionLabelsView::mousePressEvent( QMouseEvent* event )
 {
@@ -626,7 +597,6 @@ PartitionLabelsView::mousePressEvent( QMouseEvent* event )
     }
 }
 
-
 void
 PartitionLabelsView::updateGeometries()
 {
