@@ -13,8 +13,10 @@
 
 #include "partition/PartitionIterator.h"
 #include "utils/Logger.h"
+#include "utils/System.h"
+
+#include "core/KPMHelpers.h"
 
-// KPMcore
 #include <kpmcore/core/device.h>
 #include <kpmcore/core/partition.h>
 #include <kpmcore/core/partitiontable.h>
@@ -25,7 +27,7 @@
 // Qt
 #include <QProcess>
 
-using CalamaresUtils::Partition::PartitionIterator;
+using Calamares::Partition::PartitionIterator;
 
 CreatePartitionTableJob::CreatePartitionTableJob( Device* device, PartitionTable::TableType type )
     : m_device( device )
@@ -36,7 +38,7 @@ CreatePartitionTableJob::CreatePartitionTableJob( Device* device, PartitionTable
 QString
 CreatePartitionTableJob::prettyName() const
 {
-    return tr( "Create new %1 partition table on %2." )
+    return tr( "Creating new %1 partition table on %2…", "@status" )
         .arg( PartitionTable::tableTypeToName( m_type ) )
         .arg( m_device->deviceNode() );
 }
@@ -44,27 +46,23 @@ CreatePartitionTableJob::prettyName() const
 QString
 CreatePartitionTableJob::prettyDescription() const
 {
-    return tr( "Create new <strong>%1</strong> partition table on <strong>%2</strong> (%3)." )
+    return tr( "Creating new <strong>%1</strong> partition table on <strong>%2</strong> (%3)…", "@status" )
         .arg( PartitionTable::tableTypeToName( m_type ).toUpper() )
         .arg( m_device->deviceNode() )
         .arg( m_device->name() );
 }
 
-
 QString
 CreatePartitionTableJob::prettyStatusMessage() const
 {
-    return tr( "Creating new %1 partition table on %2." )
+    return tr( "Creating new %1 partition table on %2…", "@status" )
         .arg( PartitionTable::tableTypeToName( m_type ).toUpper() )
         .arg( m_device->deviceNode() );
 }
 
-
 Calamares::JobResult
 CreatePartitionTableJob::exec()
 {
-    Report report( nullptr );
-    QString message = tr( "The installer failed to create a partition table on %1." ).arg( m_device->name() );
 
     PartitionTable* table = m_device->partitionTable();
 
@@ -76,30 +74,16 @@ CreatePartitionTableJob::exec()
             cDebug() << Logger::SubEntry << ( ( *it ) ? ( *it )->deviceNode() : QString( "<null device>" ) );
         }
 
-        QProcess lsblk;
-        lsblk.setProgram( "lsblk" );
-        lsblk.setProcessChannelMode( QProcess::MergedChannels );
-        lsblk.start();
-        lsblk.waitForFinished();
-        cDebug() << Logger::SubEntry << "lsblk output:\n" << Logger::NoQuote << lsblk.readAllStandardOutput();
+        auto lsblkResult = Calamares::System::runCommand( { "lsblk" }, std::chrono::seconds( 30 ) );
+        cDebug() << Logger::SubEntry << "lsblk output:\n" << Logger::NoQuote << lsblkResult.getOutput();
 
-        QProcess mount;
-        mount.setProgram( "mount" );  // Debug output only, not mounting something
-        mount.setProcessChannelMode( QProcess::MergedChannels );
-        mount.start();
-        mount.waitForFinished();
-        cDebug() << Logger::SubEntry << "mount output:\n" << Logger::NoQuote << mount.readAllStandardOutput();
+        auto mountResult = Calamares::System::runCommand( { "mount" }, std::chrono::seconds( 30 ) );
+        cDebug() << Logger::SubEntry << "mount output:\n" << Logger::NoQuote << mountResult.getOutput();
     }
 
-    CreatePartitionTableOperation op( *m_device, table );
-    op.setStatus( Operation::StatusRunning );
-
-    if ( op.execute( report ) )
-    {
-        return Calamares::JobResult::ok();
-    }
-
-    return Calamares::JobResult::error( message, report.toText() );
+    return KPMHelpers::execute(
+        CreatePartitionTableOperation( *m_device, table ),
+        tr( "The installer failed to create a partition table on %1." ).arg( m_device->name() ) );
 }
 
 void
