@@ -35,7 +35,7 @@ private:
     QString targetPartitions() const;
 
 private:
-    CalamaresUtils::Partition::KPMManager m_kpmcore;
+    Calamares::Partition::KPMManager m_kpmcore;
     LvmDevice* m_device;
     QVector< const Partition* > m_partitionList;
 };
