@@ -41,7 +41,7 @@ AutoMountJobTests::testRunThrice()
 {
     Logger::setupLogLevel( Logger::LOGVERBOSE );
 
-    auto original = CalamaresUtils::Partition::automountDisable( true );
+    auto original = Calamares::Partition::automountDisable( true );
     cDebug() << "Got automount info" << Logger::Pointer( original );
 
     AutoMountManagementJob j( false );
@@ -49,7 +49,7 @@ AutoMountJobTests::testRunThrice()
     QVERIFY( j.exec() );
     QVERIFY( j.exec() );
 
-    CalamaresUtils::Partition::automountRestore( original );
+    Calamares::Partition::automountRestore( original );
 }
 
 void
@@ -69,8 +69,8 @@ AutoMountJobTests::testRunQueue()
     QVERIFY( !q.isRunning() );
 
     QEventLoop loop;
-    QTimer::singleShot( std::chrono::milliseconds( 100 ), [&q]() { q.start(); } );
-    QTimer::singleShot( std::chrono::milliseconds( 5000 ), [&loop]() { loop.quit(); } );
+    QTimer::singleShot( std::chrono::milliseconds( 100 ), [ &q ]() { q.start(); } );
+    QTimer::singleShot( std::chrono::milliseconds( 5000 ), [ &loop ]() { loop.quit(); } );
     connect( &q, &Calamares::JobQueue::finished, &loop, &QEventLoop::quit );
     loop.exec();
 
