@@ -10,12 +10,11 @@
 #ifndef SUMMARYPAGEPLUGIN_H
 #define SUMMARYPAGEPLUGIN_H
 
-#include <QObject>
-
-#include "utils/PluginFactory.h"
-#include "viewpages/ViewStep.h"
+#include "Config.h"
 
 #include "DllMacro.h"
+#include "utils/PluginFactory.h"
+#include "viewpages/ViewStep.h"
 
 class SummaryPage;
 
@@ -37,13 +36,14 @@ public:
     bool isAtBeginning() const override;
     bool isAtEnd() const override;
 
-    QList< Calamares::job_ptr > jobs() const override;
+    Calamares::JobList jobs() const override;
 
     void onActivate() override;
     void onLeave() override;
 
 private:
-    SummaryPage* m_widget;
+    Config* m_config = nullptr;
+    SummaryPage* m_widget = nullptr;
 };
 
 CALAMARES_PLUGIN_FACTORY_DECLARATION( SummaryViewStepFactory )
