@@ -19,6 +19,7 @@
 #include "JobQueue.h"
 #include "compat/Variant.h"
 #include "utils/Logger.h"
+#include "utils/Permissions.h"
 #include "utils/String.h"
 #include "utils/StringExpander.h"
 #include "utils/Variant.h"
@@ -927,6 +928,30 @@ tidy( QStringList& l )
     l.removeDuplicates();
 }
 
+static QString
+unscrambleYAML( const QVariant& v )
+{
+    if ( Calamares::isIntegerVariantType( v ) )
+    {
+        // YAML takes a string like "0755" and makes it an integer **anyway**
+        const auto number = v.toLongLong();
+        if ( number < 0 )
+        {
+            return QString();
+        }
+        // Since YAML has parsed it as a decimal number,
+        // turn it back into the string representation of
+        // that decimal number, even though we intended it
+        // to be octal (e.g. "755" written down becomes
+        // seven-hundred-fifty-five, needs to be the string
+        // "755" again, even though we meant octal 755 which
+        // is four-hundred-ninety-three.
+        if ( number > 777 ) { return QString(); }
+        return QString::number( number );
+    }
+    return v.toString();
+}
+
 void
 Config::setConfigurationMap( const QVariantMap& configurationMap )
 {
@@ -946,6 +971,22 @@ Config::setConfigurationMap( const QVariantMap& configurationMap )
         m_forbiddenLoginNames = Calamares::getStringList( userSettings, "forbidden_names" );
         m_forbiddenLoginNames << alwaysForbiddenLoginNames();
         tidy( m_forbiddenLoginNames );
+
+        const auto permissionKey = QStringLiteral( "home_permissions" );
+        if ( userSettings.contains( permissionKey ) )
+        {
+            const auto value = unscrambleYAML( userSettings.value( permissionKey ) );
+            m_homeDirPermissions = Calamares::parseFileMode( value );
+            if ( m_homeDirPermissions < 0 )
+            {
+                cWarning() << "Setting for" << permissionKey << '(' << value << userSettings[ permissionKey ]
+                           << ") is invalid.";
+            }
+        }
+        else
+        {
+            m_homeDirPermissions = -1;
+        }
     }
 
     setAutoLoginGroup( either< QString, const QString& >(
