@@ -28,7 +28,7 @@ class Config : public QObject
      * This is a list-model, with names and descriptions for the translations
      * available to Calamares.
      */
-    Q_PROPERTY( CalamaresUtils::Locale::TranslationsModel* languagesModel READ languagesModel CONSTANT FINAL )
+    Q_PROPERTY( Calamares::Locale::TranslationsModel* languagesModel READ languagesModel CONSTANT FINAL )
     /** @brief The requirements (from modules) and their checked-status
      *
      * The model grows rows over time as each module is checked and its
@@ -52,6 +52,7 @@ class Config : public QObject
     Q_PROPERTY( QString countryCode MEMBER m_countryCode NOTIFY countryCodeChanged FINAL )
     Q_PROPERTY( int localeIndex READ localeIndex WRITE setLocaleIndex NOTIFY localeIndexChanged )
 
+    Q_PROPERTY( QString aboutMessage READ aboutMessage CONSTANT FINAL )
     Q_PROPERTY( QString genericWelcomeMessage MEMBER m_genericWelcomeMessage NOTIFY genericWelcomeMessageChanged FINAL )
     Q_PROPERTY( QString warningMessage READ warningMessage NOTIFY warningMessageChanged FINAL )
 
@@ -89,11 +90,12 @@ public:
     QString donateUrl() const { return m_donateUrl; }
     void setDonateUrl( const QString& url );
 
+    QString aboutMessage() const;
     QString genericWelcomeMessage() const;
     QString warningMessage() const;
 
 public slots:
-    CalamaresUtils::Locale::TranslationsModel* languagesModel() const;
+    Calamares::Locale::TranslationsModel* languagesModel() const;
     void retranslate();
 
     ///@brief The **global** requirements model, from ModuleManager
@@ -120,7 +122,7 @@ signals:
 private:
     void initLanguages();
 
-    CalamaresUtils::Locale::TranslationsModel* m_languages = nullptr;
+    Calamares::Locale::TranslationsModel* m_languages = nullptr;
     std::unique_ptr< QSortFilterProxyModel > m_filtermodel;
     std::unique_ptr< GeneralRequirements > m_requirementsChecker;
 
