@@ -35,7 +35,7 @@ CheckerContainer::CheckerContainer( Config* config, QWidget* parent )
 
     mainLayout->addWidget( m_waitingWidget );
     CALAMARES_RETRANSLATE( if ( m_waitingWidget )
-                               m_waitingWidget->setText( tr( "Gathering system information..." ) ); );
+                               m_waitingWidget->setText( tr( "Gathering system information…" ) ); );
 }
 
 CheckerContainer::~CheckerContainer()
