@@ -44,7 +44,7 @@ ResultsListWidget::ResultsListWidget( Config* config, QWidget* parent )
     m_explanation->setObjectName( "resultsExplanation" );
     explanationLayout->addWidget( m_explanation );
     m_countdown = new CountdownWaitingWidget;
-    m_countdown->setToolTip( tr( "Checking requirements again in a few seconds ..." ) );
+    m_countdown->setToolTip( tr( "Checking requirements again in a few seconds…" ) );
     m_countdown->start();
     explanationLayout->addWidget( m_countdown );
 
