@@ -21,17 +21,15 @@
 #include <QObject>
 #include <QVariantMap>
 
-namespace CalamaresUtils
+namespace Calamares
 {
 namespace GeoIP
 {
 class Handler;
-}
-}  // namespace CalamaresUtils
+}  // namespace GeoIP
+}  // namespace Calamares
 
-class GeneralRequirements;
 
-// TODO: Needs a generic Calamares::QmlViewStep as base class
 // TODO: refactor and move what makes sense to base class
 class PLUGINDLLEXPORT WelcomeQmlViewStep : public Calamares::QmlViewStep
 {
@@ -58,14 +56,13 @@ public:
      * the given 2-letter country code. Uses the handler's information (if
      * given) for error reporting.
      */
-    void setCountry( const QString&, CalamaresUtils::GeoIP::Handler* handler );
+    void setCountry( const QString&, Calamares::GeoIP::Handler* handler );
 
     Calamares::RequirementsList checkRequirements() override;
     QObject* getConfig() override;
 
 private:
     Config* m_config;
-    GeneralRequirements* m_requirementsChecker;
 };
 
 CALAMARES_PLUGIN_FACTORY_DECLARATION( WelcomeQmlViewStepFactory )
